pub struct ReplicationSettings {
pub src_bucket: String,
pub dst_bucket: String,
pub dst_host: String,
pub dst_token: String,
pub entries: Vec<String>,
pub include: Vec<Label>,
pub exclude: Vec<Label>,
pub each_n: u64,
pub each_s: f64,
pub when: Option<String>,
pub mode: i32,
}Fields
src_bucket: Stringsource bucket
dst_bucket: Stringdestination bucket
dst_host: StringURL of destination host
dst_token: Stringaccess token for destination host
entries: Vec<String>list of entries to replicate, empty means all. Wildcards are allowed.
include: Vec<Label>list of labels to include
exclude: Vec<Label>list of labels to exclude
each_n: u64replicate each Nth record
each_s: f64replicate each record every N seconds
when: Option<String>condition to replicate
mode: i32replication mode
Implementations
Sourceimpl ReplicationSettings
impl ReplicationSettings
Sourcepub fn mode(&self) -> ReplicationMode
pub fn mode(&self) -> ReplicationMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: ReplicationMode)
pub fn set_mode(&mut self, value: ReplicationMode)
Sets mode to the provided enum value.